@@ -187,6 +187,8 @@ class Command(object):
                 raise CoconutException("cannot compile as both --package and --standalone")
             if args.standalone and self.mypy:
                 raise CoconutException("cannot compile as both --package (implied by --mypy) and --standalone")
+            if args.no_write and self.mypy:
+                raise CoconutException("cannot compile with --no-write when using --mypy")
             if (args.run or args.interact) and os.path.isdir(args.source):
                 if args.run:
                     raise CoconutException("source path must point to file not directory when --run is enabled")
@@ -310,7 +312,7 @@ class Command(object):
                 if not is_special_dir(name) and name.startswith("."):
                     if logger.verbose:
                         logger.show_tabulated("Skipped directory", name, "(explicitly pass as source to override).")
-                    dirnames.remove(name)  # directories removed from dirnames won't appear in further os.walk iteration
+                    dirnames.remove(name)  # directories removed from dirnames won't appear in further os.walk iterations
         return filepaths
 
     def compile_file(self, filepath, write=True, package=False, *args, **kwargs):
@@ -320,6 +322,7 @@ class Command(object):
         elif write is True:
             destpath = filepath
         else:
+            # add the name of file to the destination path
             destpath = os.path.join(write, os.path.basename(filepath))
         if destpath is not None:
             base, ext = os.path.splitext(os.path.splitext(destpath)[0])
@@ -563,12 +566,12 @@ class Command(object):
 
             logger.log("MyPy args:", self.mypy_args)
 
-    def run_mypy(self, paths=[], code=None):
+    def run_mypy(self, paths=(), code=None):
         """Run MyPy with arguments."""
         if self.mypy:
             set_mypy_path(stub_dir)
             from coconut.command.mypy import mypy_run
-            args = paths + self.mypy_args
+            args = list(paths) + self.mypy_args
             if code is not None:
                 args += ["-c", code]
             for line, is_err in mypy_run(args):
@@ -640,9 +643,16 @@ class Command(object):
         logger.show_tabulated("Watching", showpath(source), "(press Ctrl-C to end)...")
 
         def recompile(path):
+            path = fixpath(path)
             if os.path.isfile(path) and os.path.splitext(path)[1] in code_exts:
                 with self.handling_exceptions():
-                    filepaths = self.compile_path(path, write, package, run, force, show_unchanged=False)
+                    if write is True or write is None:
+                        writedir = write
+                    else:
+                        # correct the compilation path based on the relative position of path to source
+                        dirpath = os.path.dirname(path)
+                        writedir = os.path.join(write, os.path.relpath(dirpath, source))
+                    filepaths = self.compile_path(path, writedir, package, run, force, show_unchanged=False)
                     self.run_mypy(filepaths)
 
         watcher = RecompilationWatcher(recompile)
