@@ -128,23 +128,25 @@ all_reqs = {
 min_versions = {
     "pyparsing": (2, 2, 0),
     "cPyparsing": (2, 2, 0, 1, 1),
-    "pre-commit": (0, 18),
-    "sphinx": (1, 6),
+    "pre-commit": (1,),
     "pygments": (2, 2),
     "recommonmark": (0, 4),
-    "sphinx_bootstrap_theme": (0, 6),
-    "psutil": (5, 3),
+    "psutil": (5,),
     "jupyter": (1, 0),
     "jupyter-console": (5, 2),
-    "ipython": (5, 4),
     "ipykernel": (4, 6),
-    "mypy": (0, 521),
+    "mypy": (0, 540),
     "prompt_toolkit": (1, 0),
     "futures": (3, 1),
     "argparse": (1, 4),
     "pytest": (3,),
     "watchdog": (0, 8),
     "requests": (2,),
+    # We can't upgrade this; it breaks on Python 2.
+    "ipython": (5, 4),
+    # Don't upgrade these; they break on master!
+    "sphinx": (1, 6, 2),
+    "sphinx_bootstrap_theme": (0, 4),
 }
 
 version_strictly = (
@@ -335,6 +337,7 @@ tre_mock_var = reserved_prefix + "_mock_func"
 tre_store_var = reserved_prefix + "_recursive_func"
 none_coalesce_var = reserved_prefix + "_none_coalesce_item"
 sentinel_var = reserved_prefix + "_sentinel"
+
 # prefer Matcher.get_temp_var to proliferating more match vars here
 match_to_var = reserved_prefix + "_match_to"
 match_to_args_var = match_to_var + "_args"
@@ -427,7 +430,8 @@ py3_to_py2_stdlib = {
     "urllib.error": ("urllib2", (3,)),
     "pickle": ("cPickle", (3,)),
     "collections.abc": ("collections", (3, 3)),
-    "io.StringIO": ("StringIO./StringIO", (2, 7)),  # ./ denotes from ... import ...
+    # ./ denotes from ... import ...
+    "io.StringIO": ("StringIO./StringIO", (2, 7)),
     "io.BytesIO": ("cStringIO./StringIO", (2, 7)),
 }
 
@@ -491,9 +495,12 @@ verbose_mypy_args = (
     "--warn-incomplete-stub",
     "--warn-redundant-casts",
     "--warn-return-any",
-    "--warn-unused-ignores",
+    "--warn-unused-configs",
+    "--show-error-context",
 )
 
+oserror_retcode = 127
+
 #-----------------------------------------------------------------------------------------------------------------------
 # HIGHLIGHTER CONSTANTS:
 #-----------------------------------------------------------------------------------------------------------------------
